@@ -40,7 +40,7 @@ double dinvtrgamma(double x, double shape1, double shape2, double scale,
     logu = shape2 * (log(scale) - log(x));
 
     return R_D_exp(log(shape2) + shape1 * logu - exp(logu)
-                   - log(x) - lgamma(shape1));
+                   - log(x) - lgammafn(shape1));
 }
 
 double pinvtrgamma(double q, double shape1, double shape2, double scale,
@@ -104,9 +104,11 @@ double minvtrgamma(double order, double shape1, double shape2, double scale,
         !R_FINITE(order)  ||
         shape1 <= 0.0 ||
         shape2 <= 0.0 ||
-        scale  <= 0.0 ||
-        order  >= shape1 * shape2)
-        return R_NaN;;
+        scale  <= 0.0)
+        return R_NaN;
+
+    if (order  >= shape1 * shape2)
+	return R_PosInf;
 
     return R_pow(scale, order) * gammafn(shape1 - order / shape2)
         / gammafn(shape1);
@@ -123,12 +125,14 @@ double levinvtrgamma(double limit, double shape1, double shape2, double scale,
         !R_FINITE(order)  ||
         shape1 <= 0.0 ||
         shape2 <= 0.0 ||
-        scale  <= 0.0 ||
-        order >= shape1 * shape2)
-        return R_NaN;;
+        scale  <= 0.0)
+        return R_NaN;
+
+    if (order >= shape1 * shape2)
+	return R_PosInf;
 
     if (limit <= 0.0)
-        return 0;
+        return 0.0;
 
     tmp = shape1 - order / shape2;
 
